<?php

namespace App\Providers;

use Illuminate\Cache\RateLimiting\Limit;
use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\RateLimiter;
use Illuminate\Support\Facades\Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * The path to the "home" route for your application.
     *
     * Typically, users are redirected here after authentication.
     *
     * @var string
     */
    public const HOME         = '/dashboard';

    public const ADMIN        = '/admin';

    public const ORGANIZATION = '/organization';

    public const INSTRUCTOR   = '/instructor';

    public const STUDENT      = '/my-profile';

    /**
     * Define your route model bindings, pattern filters, and other route configuration.
     *
     * @return void
     */
    public function boot()
    {
        $this->configureRateLimiting();

        $this->routes(function () {

            Route::middleware('web')
                ->group(base_path('routes/install.php'));

            Route::middleware('api')
                ->prefix('api')
                ->group(base_path('routes/api.php'));
            Route::middleware('api')
                ->prefix('api')
                ->group(base_path('routes/instructor-api.php'));

            Route::middleware(['web', 'isInstalled'])
                ->group(base_path('routes/web.php'));

            Route::middleware(['web', 'isInstalled'])
                ->group(base_path('routes/admin.php'));

            Route::middleware(['web', 'isInstalled', 'auth', 'verified', 'orgazinationStaff'])
                ->name('organization.')
                ->group(base_path('routes/organization.php'));

            Route::middleware(['web', 'isInstalled', 'auth', 'verified', 'instructorCheck'])
                ->name('instructor.')
                ->group(base_path('routes/instructor.php'));
        });
    }

    /**
     * Configure the rate limiters for the application.
     *
     * @return void
     */
    protected function configureRateLimiting()
    {
        RateLimiter::for('api', function (Request $request) {
            return Limit::perMinute(60)->by($request->user()?->id ?: $request->ip());
        });
    }
}
